#
# spec file for package gcompris-qt
#
# Copyright (c) 2019 SUSE LLC
# Copyright (c) 2019 Ioda-Net Sàrl, Charmoille, Switzerland. Bruno Friedmann
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gcompris-qt
Version:        0.97
Release:        lp152.1.1
Summary:        Multiactivity educational software for children aged 2–10 (Qt version)
License:        GPL-3.0-or-later
Group:          Amusements/Teaching/Other
URL:            https://gcompris.net
Source0:        https://gcompris.net/download/qt/src/%{name}-%{version}.tar.xz
Source1:        https://gcompris.net/download/qt/src/%{name}-%{version}.tar.xz.sig
Source2:        https://share.kde.org/index.php/s/YjKzYs1bgDsOo5V/download#/%{name}.keyring
Source3:        gcompris-qt-rpmlintrc
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  libBox2D-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  qml-box2d
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.6.0
# We don't want the Administrative documentation
# BuildRequires:  kdoctools-devel
BuildRequires:  pkgconfig(Qt5Core) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Multimedia) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.6.0
BuildRequires:  pkgconfig(Qt5OpenGL) >= 5.6.0
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Quick) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Script) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Sensors) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Svg) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Xml) >= 5.6.0
BuildRequires:  pkgconfig(Qt5XmlPatterns) >= 5.6.0
BuildRequires:  pkgconfig(openssl)
# Runtime requirements, it doesn't start without them (boo#1011125)
Requires:       %{name}-activities = %{version}
Requires:       libQt5Multimedia5 >= 5.6.0
Requires:       libQt5Svg5 >= 5.6.0
Requires:       libqt5-qtgraphicaleffects >= 5.6.0
Requires:       libqt5-qtquickcontrols >= 5.6.0
Requires:       qml-box2d
Recommends:     %{name}-lang = %{version}
Recommends:     %{name}-voices = %{version}
Provides:       gcompris = 17.10
Obsoletes:      gcompris < 17.10

%description
GCompris-Qt is an educational software suite comprising
of numerous activities for children aged 2 to 10. Some of the
activities are game orientated, but nonetheless still educational.

Currently, GCompris offers in excess of 100 activities. New
activities can be added, and an activity can implement its own game
scheme.

This version is a rewrite of GCompris using the QtQuick
technology.

%package activities
Summary:        Activity files for %{name}
Group:          Amusements/Teaching/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description activities
This package contains the bundle of activities for %{name}.
More than 100 activities are available.

%package lang
# FIXME: consider using %%lang_package macro
Summary:        Translation files for %{name}
Group:          Amusements/Teaching/Other
Requires:       %{name} = %{version}
Obsoletes:      %{name}-translations < %{version}-%{release}
Provides:       %{name}-translations = %{version}-%{release}
BuildArch:      noarch

%description lang
This package contains the bundle of translations for %{name}.
More than 30 languages are available, and allow you to run
GCompris in different languages and play activities.

%prep
%setup -q

%build
export LDFLAGS="-Wl,-z,relro,-z,now -pie"
export CFLAGS="%{optflags} -fPIE -pie -fno-strict-aliasing -DNDEBUG"
export CXXFLAGS="%{optflags} -fPIE -pie -fno-strict-aliasing -DNDEBUG"

find . -name CMakeLists.txt \
  -exec sed -i -re '/^[[:blank:]]*[sS][eE][tT][[:blank:]]*\([[:blank:]]*(CMAKE_BUILD_TYPE|CMAKE_COLOR_MAKEFILE|CMAKE_INSTALL_PREFIX|CMAKE_VERBOSE_MAKEFILE).*\)/{s/^/#IGNORE /}' {} +
%cmake_kf5 -d build

%make_build
# Build translastions too.
%make_build BuildTranslations

%install
%cmake_install
#Fix wrong place of man page temporaly
rm -fr %{buildroot}/%{_prefix}/man
# Install desktop file
install -d %{buildroot}/%{_datadir}/applications
install org.kde.gcompris.desktop %{buildroot}/%{_datadir}/applications/org.kde.gcompris.desktop
%suse_update_desktop_file org.kde.gcompris Education Math Languages
# Install icon file
install -d %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/
install -m 644 images/sc-apps-gcompris-qt.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/gcompris-qt.svg

%files
%license COPYING
%doc README.rst
%{_bindir}/%{name}
%{_datadir}/icons/hicolor/256x256/
%{_datadir}/icons/hicolor/256x256/apps
%{_datadir}/applications/org.kde.gcompris.desktop
%{_datadir}/icons/hicolor/256x256/apps/gcompris-qt.png
%{_datadir}/icons/hicolor/scalable/apps/gcompris-qt.svg
%{_datadir}/metainfo/org.kde.gcompris.appdata.xml

%files activities
%license COPYING
%doc README.rst
#Activities
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/rcc
%{_datadir}/%{name}/rcc/*.rcc

%files lang
%license COPYING
%doc README.rst
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/*.qm

%changelog
* Tue Dec 10 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Upgrade to version 0.97
  This new version contains 2 new activities:
  + A programming maze: to learn the basics of programming with a
    few instructions
  + Baby tangram: to learn the basics of tangram
  New features:
  + new sub-categories to organize activities
  + new background music feature and audio tracks
  + new volume settings for audio effects
  + new speed setting in several activities (gletters, algebra,
    readingh, note_names)
  + new feature in chess activities to display captured pieces
  + new option to go to next level manually in drawletters and drawnumbers
  + new voices for en_US
  + new images for colors activity
  + new images for advanced_colors activity
  + new images for target activity
  + improve settings layout
  + improve share activity layout
  + improve categorisation activity layout
  + resource files are now stored in KDE server (https://cdn.kde.org/)
  + add a tutorial to even/odd numbers
  + add intro to piano_composition
  + add malayalam dataset to gletters
  + add breton dataset to wordsgame
  + fix voices not playing in geography
  + fix sounds not playing in mining
  + fix portrait mode in binary_bulb
  + fix high cpu load in menu
  + fix hint image size in photo_hunter
  + fix layout in color_mix
  and lots of other small fixes...
- Packaging spec-clean minimal (copyright, deps order)
- Update url to https scheme
* Mon Sep  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Set valid categories in desktop file
- Do not install appdata twice
- Remove obsolete code from specfile
* Mon Mar  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Upgrade to version 0.96
  + Includes updated translation for several languages,
  and a few bug fixes.
  + Translations that received a big update:
  - Brazilian Portuguese (100%%)
  - Breton (100%%)
  - Finnish (90%%)
  - Indonesian (100%%)
  - Norwegian Nynorsk (97%%)
  - Polish (100%%)
  + All download are now made with https.
  + Known issues: the progress bar for downloads doesn’t work
    anymore due to https usage.
- Packaging small clean-up (trailing space)
* Fri Jan  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Upgrade to version 0.95
  + New activities
    Binary bulbs: to learn how to count in binary
    Railroad activity: to train visual memory
    Solar System: to learn about our solar system
    Name that Note: to learn to recognize musical notes and names
    Play Piano: to train reading notes on a score
    Play Rhythm: to train following a musical rhythm
    Piano Composition: to learn composition of a musical score
  + Languages
    15 languages fully supported
    19 languages partially supported (<80%% translated)
    Time to help the project, see website
  + OpenGL is now tried by default, if not working you can still
    use software rendering see release note howto do that
  + This is the last release that support Qt 5.6 (Leap 42.3)
- Packaging
  + Remove upstream merged patch 35278731_0.91_backport.patch
  + Renew spec file with spec-cleaner
* Mon Jun 11 2018 bruno@ioda-net.ch
- Really fix 42.3 with defined %%mail_build
* Mon Jun 11 2018 bruno@ioda-net.ch
- Backport upstream fix qt5_use_modules is deprecated in Qt 5.11
  https://cgit.kde.org/gcompris.git/patch/?id=35278731
  35278731_0.91_backport.patch
* Mon May 21 2018 bruno@ioda-net.ch
- Fix broken build Leap 42.3 by defining %%make_build if not exist
* Sun May 20 2018 astieger@suse.com
- add upstring keyring to verify source signature
* Thu May 17 2018 bruno@ioda-net.ch
- Upgrade to new 0.91 version
  summary of changes
  + Activities:
  - fix English text in several activities
  - fix score position in several activities
  - block some buttons and interactions when needed in several
    places
  - lots of fixes for audio in several activities
  - number_sequence (and others based on it), fix base layout
  - update dataset for clickanddraw, drawnumbers and drawletters
  - crane, add localized dataset
  - lightsoff, add keyboard support and other fixes
  - algorithm, add keyboard support and other fixes
  - money, fixes for locale currency used
  - ballcatch, improve audio feedback
  - calendar, several little fixes
  - memory-case-association fix icons size
  ° Other changes:
  - re-enable sound effects on linux
  - improved playback of sound effects, no more delay
  - add captions to images and OARS tags in the appdata
  - add Scottish Gaelic to core, and update some datasets for it
  - main bar, fix some items size
  - remove unused images
  + Translations
  16 languages fully supported: British English, Catalan, Catalan
  (Valencian), Chinese Traditional, Dutch, French, Greek,
  Indonesian, Irish Gaelic, Italian, Polish, Portuguese, Romanian,
  Spanish, Swedish, Ukrainian.
  15 languages partially supported: Norwegian Nynorsk (97%%), Hindi
  (96%%), Turkish (90%%), Scottish Gaelic (86%%), Galician (86%%),
  Brazilian Portuguese (84%%), Belarusian (84%%), German (81%%),
  Chinese Simplified (79%%), Russian (78%%), Estonian (77%%), Slovak
  (76%%), Finnish (76%%), Slovenian (69%%), Breton (65%%).
  If you want to help completing one of these translations or
  adding a new one, please contact upstream.
* Tue Mar 20 2018 mimi.vx@gmail.com
- Provide and obsolette original gtk gcompris
- use secure optflags on all distributions.
- and use proper cmake macros for build
* Wed Mar 14 2018 bruno@ioda-net.ch
- Upgrade to new 0.90 version
  + 8 new activities:
  * A calendar activity where the child learns how to use it
  * Another activity based on calendar where the child has to find
    the date corresponding at a date + some days further/before
    this date
  * An activity to learn how people on a family are related and how
    to call this relation
  * Another similar activity with questions about family members
  * An extension of memory activities where the child has to match
    lowercase letters with their corresponding uppercase
  * The same activity in two players mode with Tux
  * The Gtk+ port and improved submarine activity where the child
    learns a basic overview on how to run a submarine
  * The digital electricity activity where the child can use
    different components to create an electric schema. There is also
    a tutorial mode to explain how to use each component
  + bug fixes:
  * Irish translation, voices and datasets by Séamus Ó Briain
  * Updated graphics on several activities
  * Lot of improvements on removing overriding elements issues
    (score were hidden behind the bar...)
  * Add Tutorial item to be able to have activity introductions
    with both images and texts
  * Add easy mode in letter in word with less words displayed
  * Add license page
  * Lots of small bug fixes
- Modernize spec file with spec-cleaner -m
* Sat Sep 30 2017 bruno@ioda-net.ch
- Upgrade to bugfix release 0.81 the most important changes are:
  + Categorization, fix the "Shape" category
  + Categorization, fix the menu layout
  + Categorization, display score in expert mode
  + Guesscount, fix invalid result
  + Add Indonesian locale
  + Fix the missing copyright and licence info
  + Fix a font issue on windows version
  + Add a new minimal version with software rendering
    (requires Qt 5.8)
* Sat Aug 26 2017 bruno@ioda-net.ch
- Upgrade to last release 0.80
  This new version contains 6 new activities:
  + a categorization activity where the child has to categorize
    item depending on the theme (by Divyam Madaan)
  + a guess count game where the child has to find the good
    operations to find a given number (by Rahul Yadav)
  + a game where you have to let the computer put the last ball in
    a row (by Utkarsh Tiwari)
  + as above but the child plays with a friend (Utkarsh Tiwari)
  + a checkers game (by Johnny Jazeix)
  + as above but the child plays with a friend (by Johnny Jazeix)
  We always have new features and content:
  + Polish lang dataset by Łukasz Wojniłowicz
  + Swedish lang dataset by Stefan Asserhäll
  + Ukrainian lang dataset by Yuri Chornoivan
  + new icons
  + Updated graphics on several activities
  + lots of bug fixes
  + website translation migrated to KDE infrastructure and
    translated in Belarusian, Catalan, Catalan (Valencia),
    Romanian, Portuguese and Ukrainian
  + new mingw windows builds
  + partial translations in Greek and Hindi
- Packaging :
  + Fix icons included (the real svg is used now upstream)
  + Add appinfo and metainfo
  + Raise minimal QT version to be >= 5.6.0 upstream #6c203a3
* Mon Feb 13 2017 bruno@ioda-net.ch
- Add missing requires : libQt5Svg5 and qml-box2d that obs/rpm
  doesn't add when they should.
  Fixing empty gcompris-qt on pure leap Gnome3 installation.
- Add missing desktop, appdata, icon files
- Fix copyright year
* Sat Dec 24 2016 bruno@ioda-net.ch
- New 0.70 version contains 8 new activities, half of them being
  created by last Google Summer of Code students:
  * an activity where the child has to move elements to build a
    given model (crane by Stefan Toncu)
  * an activity to draw the numbers (drawnumbers by Nitish Chauhan)
  * an activity to draw the letters (drawletters by Nitish Chauhan)
  * an activity to find on which words a given letter belongs
    (letter-in-word by Akshat Tandon)
  * the nine men morris game against Tux (nine_men_morris by Pulkit
    Gupta)
  * the nine men morris game with a friend
    (nine_men_morris_2_players by Pulkit Gupta)
  * an activity to learn to split a given number of candies amongst
    children (share by Stefan Toncu)
  * an activity to learn roman numbers (roman_numerals by Bruno
    Coudoin)
  + new features and bug fixes:
  * search feature by Rishabh Gupta
  * windows build by Bruno Coudoin and Johnny Jazeix
  * hint icon in the bar (used in photohunter) by Johnny Jazeix
  * neon build by Jonathan Riddell
  * openSUSE Tumbleweed build by Bruno Friedmann
  * archlinux (https://aur.archlinux.org/packages/gcompris-qt/)
    by Jose Riha
  * KaOS (http://kaosx.tk/packages/index.php?act=show&subdir=\
    build&sortby=date&file=gcompris-0.70-1-x86_64.pkg.tar.xz)
    by demm
  * package on mageia cauldron by Timothee Giet
  * word list for Slovakia by Jose Riha
  * word list for Belarusian by Antos Vaclauski
  * updates on Romanian wordlists and voices by Horia Pelle
  * voices added for Portuguese Brazilian by Marcos D.
  * new graphics for crane by Timothee Giet
  * screenshots on gcompris.net updated to the Qt version
- Update gcompris-qt-voices to 20161224 version
* Mon Nov 21 2016 wbauer@tmo.at
- Also require libqt5-qtgraphicaleffects, that's needed too
* Sat Nov 19 2016 wbauer@tmo.at
- Require libQt5Multimedia5 and libqt5-qtquickcontrols, it doesn't
  start without them (boo#1011125)
* Mon Aug  8 2016 bruno@ioda-net.ch
- Update to last bugfix enhancement upstream revision 0.61
  Complete release changes at http://gcompris.net/news-en.html
  + New activities are:
    baby_word_processor
    tangram
    explore_momuments
    graph_coloring
    land_safe
    photo_hunter
  + Updated images for chess, hangman and horizontal/vertical
    reading activities along with the gcompris logo.
  + Lots of little fixes/improvements have been done (storing and
    restoring the window's width/height at start-up, docbook
    updated, levels/images bonus, adding an internal dataset for
    words games so that we no more expect the network to run
    GCompris.
  + Translation side 17 languages fully supported:
    Belarusian, British English, Brazilian Portuguese, Catalan,
    Catalan (Valencian), Chinese Simplified, Dutch, French,
    Galician, Italian, Norwegian Nynorsk, Polish, Portuguese,
    Romanian, Spanish, Swedish, Ukrainian.
  + some partially: Breton (88%%), Chinese Traditional (97%%),
    Estonian (82%%), Finnish (74%%), German (93%%), Russian (83%%),
    Slovak (76%%), Slovenian (82%%), Turkish (82%%)
* Wed Jul 27 2016 jengelh@inai.de
- Split voices off to separate SRPM
- Rename -translations subpackage to -lang
* Fri Jul 22 2016 jengelh@inai.de
- Set data file subpackages to noarch. Trim long description.
* Sun Jul 17 2016 bruno@ioda-net.ch
- Added also as sources in spec
  + gcompris-qt-rpmlintrc
  + fetch_voices.sh
* Tue Jul  5 2016 bruno@ioda-net.ch
- Fixed definitively upstream src url checked with obs service.
* Sun Jul  3 2016 bruno@ioda-net.ch
- Packaging :
  + fix upstream url source
  + Remove second %%changelog
  + Add rpmlintrc (man page for binary)
- Refresh voices.tar.xz with recent upstream updates
* Wed May 25 2016 bruno@ioda-net.ch
- Update to upstream 0.60 new version
- remove merged upstream-fix-compilation-on-openSUSE.patch
* Wed Jan 20 2016 bruno@ioda-net.ch
- Added upstream patch fixing build errors on 13.2
  upstream-fix-compilation-on-openSUSE.patch
* Mon Jan 18 2016 bruno@ioda-net.ch
- Update to upstream 0.52 new version
  It includes all the little patches and improvements from master (
  without new activities or features). Most important is the
  lang activity that was not available in French.
- Remove upstream merged patches
  add-option-to-disable-qml-box2d-module-and-depending-activites.patch
  robustify_Qt-plugin_and_qml-path_detection.patch
- Refreshed content of voices-ogg
* Sat Jan  2 2016 bruno@ioda-net.ch
- Added upstream patch for Box2D qml-box2d detection
  robustify_Qt-plugin_and_qml-path_detection.patch
* Sun Dec 27 2015 bruno@ioda-net.ch
- Update to new upstream 0.50 release
- Added add-option-to-disable-qml-box2d-module-and-depending\
  - activites.patch in case qml-box2d is not available
- Recreated voices tar.xz for 0.50 version
- Upstream move to tar.xz format
- Added deps to libBox2D-devel
* Sat Sep 12 2015 bruno@ioda-net.ch
- Initial packaging for obs for gcompris-qt the new qt based.
- The packaging is done by splitting translations, activities, and
  voices from the main binaries.
  Activities is the only one required package for main build.
- Translations allow people to run gcompris-qt in foreign language
- Videos package is useful for people who want to have complete
  offline experience.
